/// <reference types="node" />
/// <reference types="node" />
import crypto from 'crypto';
import { ASN1Obj } from './asn1/obj';
import { x509AuthorityKeyIDExtension, x509BasicConstraintsExtension, x509KeyUsageExtension, x509SCTExtension, x509SubjectAlternativeNameExtension, x509SubjectKeyIDExtension } from './ext';
export declare class x509Certificate {
    root: ASN1Obj;
    constructor(asn1: ASN1Obj);
    static parse(cert: Buffer | string): x509Certificate;
    get tbsCertificate(): Buffer;
    get version(): string;
    get notBefore(): Date;
    get notAfter(): Date;
    get issuer(): Buffer;
    get subject(): Buffer;
    get publicKey(): crypto.KeyObject;
    get signatureAlgorithm(): string;
    get signatureValue(): Buffer;
    get extKeyUsage(): x509KeyUsageExtension | undefined;
    get extBasicConstraints(): x509BasicConstraintsExtension | undefined;
    get extSubjectAltName(): x509SubjectAlternativeNameExtension | undefined;
    get extAuthorityKeyID(): x509AuthorityKeyIDExtension | undefined;
    get extSubjectKeyID(): x509SubjectKeyIDExtension | undefined;
    get extSCT(): x509SCTExtension | undefined;
    get isCA(): boolean;
    verify(issuerCertificate?: x509Certificate): boolean;
    validForDate(date: Date): boolean;
    equals(other: x509Certificate): boolean;
    private findExtension;
    private checkRecognizedExtensions;
    private get tbsCertificateObj();
    private get signatureAlgorithmObj();
    private get signatureValueObj();
    private get versionObj();
    private get issuerObj();
    private get validityObj();
    private get subjectObj();
    private get subjectPublicKeyInfoObj();
    private get extensionsObj();
}
